Archetypon
================

<!-- WARNING: THIS FILE WAS AUTOGENERATED! DO NOT EDIT! -->

`archetypon` (pronounced “archetype on”) is a library that uses Pydantic
to validate Pandas Dataframes. It includes some usefull extensions of
Pydantic’s BaseModel class display models in Jupyter Notebooks and
Jupyter Lab.

It’s built using `nbdev`

## Install

``` sh
pip install archetypon
```

## Example
